@@ -3,17 +3,17 @@ package Number::ZipCode::JP::Table::Company;
 use strict;
 use warnings;
 
-our $VERSION = '0.20120629';
+our $VERSION = '0.20120731';
 
-# Table last modified: 2012-06-29
+# Table last modified: 2012-07-31
 our %ZIP_TABLE = (
     '001' => '(?:8(?:5(?:[02]1|88)|612))',
     '002' => '(?:850[1-4])',
     '003' => '(?:8(?:5(?:58|8[0-258]|0[1-5]|3[01]|1[0159]|7[07]|6[67])|6(?:01|40|68|3[019]|1[02])|70[125]))',
-    '004' => '(?:8(?:5(?:77|2[23]|8[58]|5[058]|3[013]|1[0258]|6[07]|0[235])|6(?:[34]1|29|0[23]|1[0-368])))',
+    '004' => '(?:8(?:5(?:23|77|8[58]|5[058]|3[013]|1[0258]|6[07]|0[235])|6(?:[34]1|29|0[23]|1[0-368])))',
     '005' => '(?:8(?:5(?:[58]5|01|43)|6(?:12|0[12])|798))',
     '006' => '(?:8(?:5(?:[23]0|[58]5|61)|612))',
-    '007' => '(?:8(?:50[13578]|632))',
+    '007' => '(?:8(?:5(?:85|0[13578])|632))',
     '010' => '(?:(?:8(?:5(?:43|6[04]|3[03]|2[025]|8[058]|0[12457]|1[58]|5[08]|7[0247])|6(?:[01]1|22|33|55|68|7[78])|794)|0(?:49[2-4]|[15]95)|1(?:49[2-4]|292)))',
     '011' => '(?:8(?:5(?:[58]5|01|20|77|1[01])|6(?:05|11|86)))',
     '012' => '(?:8(?:5(?:11|0[12])|6(?:51|0[14])))',
@@ -103,20 +103,20 @@ our %ZIP_TABLE = (
     '097' => '(?:8(?:5(?:10|85|5[58]|2[57])|6(?:[03]9|[68]6)))',
     '098' => '(?:(?:5(?:[78]92|298|595)|(?:28|62|0[13])92|1(?:69[23]|792)|339[23568]))',
     '099' => '(?:(?:2(?:19[2-8]|49[235]|392)|1(?:49[2568]|19[78]|595)|3(?:29[23]|69[78])|4(?:19[256]|492)|(?:56|65)92|049[245]))',
-    '100' => '(?:(?:8(?:9(?:4[015]|8[0-35-79]|6[0-25-9]|7[0-2457-9]|2[0-24-79]|9[46]|3[0137]|1[02-9]|0[1-579]|5[0-3569])|1(?:3[01589]|6\d|0[2358]|4[0149]|5[016-8]|8[0-26-9]|7[1-37]|1[01357-9]|2[0-3568])|6(?:55|86|2[019]|1[057]|3[0-29]|7[067]|6[3568]|0[268]|4[049])|3(?:66|70|5[015]|0[2378]|4[158]|2[1245]|3[138]|1[01]|8[038])|2(?:46|70|6[02578]|2[78]|8[2358]|0[13]|1[014-69]|3[2-4])|5(?:11|4[03]|5[058]|2[02]|6[07]|8[58]|7[57]|0[35-7])|4(?:02|56|1[015]|2[0147]|3[09]|4[048]|8[48])|0(?:19|66|7[07-9]|8[68]|5[01])|79[158])|6(?:1(?:62|7[0-578]|5[0-2])|2(?:55|77|6[02])|0(?:66|80)|75[1-6])|149[28]|3131))',
+    '100' => '(?:(?:8(?:9(?:4[015]|8[0-35-79]|6[0-25-9]|7[0-2457-9]|2[0-24-79]|9[46]|3[0137]|1[02-9]|0[1-579]|5[0-3569])|1(?:3[01589]|6\d|0[2358]|4[0149]|5[016-8]|8[0-26-9]|7[1-37]|1[01357-9]|2[0-3568])|2(?:46|70|5[1-3]|6[02578]|2[78]|8[2358]|0[13]|1[014-69]|3[2-4])|6(?:55|86|2[019]|1[057]|3[0-29]|7[067]|6[3568]|0[268]|4[049])|3(?:66|70|5[015]|0[2378]|4[158]|2[1245]|3[138]|1[01]|8[038])|5(?:11|4[03]|5[058]|2[02]|6[07]|8[58]|7[57]|0[35-7])|4(?:02|56|1[015]|2[0147]|3[09]|4[048]|8[48])|0(?:19|66|7[07-9]|8[68]|5[01])|79[158])|6(?:1(?:62|7[0-578]|5[0-2])|2(?:55|77|6[02])|0(?:66|80)|75[1-6])|149[28]|3131))',
     '101' => '(?:8(?:4(?:7[05-7]|2[1-57]|8[13]|0[57-9]|3[0379]|5[0-4689]|4[13-9]|6[04-9]|1[0-25689])|3(?:3[135]|0[1257-9]|8[01358]|6[02356]|7[0158]|5[0-689]|2[1-8]|1[013-7]|4[56])|5(?:6[0-2568]|5[289]|4[2-5]|8[1568]|1[0-2459]|7[6-9]|0[1-46-9]|3[0-5]|2[0-3568])|6(?:8[28]|0[5-79]|1[0-379]|6[2578]|3[0346-8]|5[14-6]|4[1-3568]|7[026]|2[0-24-9])|9(?:[019]1|35|50|7[0-37]|4[16]|8[036])|7(?:0[137]|1[0-25-8])|0(?:11|50|77|0[12])|20[1-4]|101))',
     '102' => '(?:8(?:4(?:5[0-2569]|8[13489]|6[0-24-68]|4[057]|2[014679]|0[125-7]|1[014579]|7[0478]|3[0-3578])|1(?:1[0-278]|5[0-25]|3[0-289]|7[0-25-8]|8[0-24-8]|2[02358]|0[1-359]|4[0-24]|6[016])|6(?:3[0-3579]|4[245]|2[016-8]|8[0589]|7[17-9]|0[1-479]|1[0-47-9]|5[016]|6[06-8])|5(?:0[2-468]|5[024-9]|2[0289]|6[079]|3[0139]|4[013]|8[0458]|1[01568]|7[013578])|3(?:4[19]|1[0134]|3[1-356]|8[1-38]|6[24]|7[0237]|5[035-7]|0[1-359]|2[0-24])|2(?:88|5[015]|1[158]|7[257]|2[2568]|3[0-2468]|0[15]|6[0245]|4[016])|0(?:08|22|77|8[0-35]|1[125689])|79[58]))',
     '103' => '(?:8(?:2(?:0[1-6]|1[0-2478]|6[0135]|4[0-35-8]|7[02358]|3[0-8]|8[457]|2[124589]|5[0-25689])|4(?:4[348]|7[0-3]|2[2-7]|0[1-57]|3[0-57-9]|1[0-79]|6[0-24-6]|8[01467]|5[016])|5(?:0[1-367]|4[2358]|8[4-689]|2[0-25]|5[24-68]|3[013-8]|6[067]|7[0157]|1[0-2])|3(?:7[03]|5[0-2458]|0[136-8]|8[0348]|2[01348]|4[15-7]|1[0137]|6[036]|3[01357-9])|6(?:7[05-7]|6[0568]|8[0469]|5[0-36]|3[1269]|4[014])|0[01]1))',
     '104' => '(?:(?:8(?:1(?:2[2-589]|3[0-58]|0[124-689]|5[158]|8[0139]|1[124-8]|4[25]|6[1-8]|7[0-25-8])|4(?:3[013-689]|4[03-578]|1[015689]|8[168]|0[1-8]|[67][068]|5[0156]|2[0-59])|5(?:1[028]|3[035689]|4[0468]|5[0134689]|7[02]|2[0138]|6[036-8]|0[1256]|8[014578])|3(?:6[015]|4[04]|1[0-3579]|2[014589]|5[167]|7[27]|3[02358]|8[038]|0[2-59])|2(?:4[03]|1[0-258]|3[38]|2[28]|0[568]|5[0-35-7]|7[07]|6[026]|8[0-24589])|6(?:50|6[0158]|8[05]|7[08])|0(?:55|77|1[01]|0[1347]))|6241))',
-    '105' => '(?:(?:8(?:4(?:3[2-79]|0[1-578]|1[0-24-689]|8[2-8]|5[0-35-8]|2[0247-9]|7[0-39]|4[014-9]|6[01457])|5(?:2[0-357-9]|1[0-2578]|8[0-2457-9]|0[57-9]|5[02-8]|7[4-9]|4[35689]|6[0378]|3[0457])|6(?:54|6[0568]|1[01348]|4[02]|7[078]|3[014]|8[05-9]|2[1346]|0[3468])|0(?:20|55|0[12578]|7[07]|8[58]|1[0-2])|3(?:01|22|33|1[0-3])|7(?:0[127]|1[1267]))|7444))',
+    '105' => '(?:(?:8(?:4(?:3[2-79]|0[1-578]|1[0-24-689]|8[2-8]|5[0-35-8]|2[0247-9]|7[0-39]|4[014-9]|6[01457])|5(?:2[0-357-9]|1[0-2578]|8[0-2457-9]|0[57-9]|5[02-8]|7[4-9]|4[35689]|6[0378]|3[0457])|6(?:54|6[0568]|1[01348]|4[02]|7[078]|3[014]|8[05-9]|2[1346]|0[3468])|0(?:20|55|0[12578]|7[07]|8[58]|1[0-2])|3(?:01|22|3[03]|1[0-3])|7(?:0[127]|1[1267]))|7444))',
     '106' => '(?:(?:8(?:5(?:08|4[134]|6[0-35-79]|7[136-8]|1[458]|3[0-25]|2[12]|5[0-35689]|8[0157-9])|6(?:77|6[158]|5[25]|1[168]|0[18]|2[0256]|8[15]|3[069]|4[0-24589])|0(?:[01]1|39)|7(?:11|97)|401)|6(?:1(?:61|88)|06[06])))',
-    '107' => '(?:8(?:5(?:8[13589]|2[0-2578]|5[0-26-8]|4[356]|3[02]|0[258]|7[0579]|6[0357]|1[15])|6(?:42|8[06]|2[023578]|6[6-8]|1[15-79]|0[14]|7[46]|3[0-3689]|5[05])|4(?:34|56|77|2[03]|0[134]|1[0-24679]|8[24]|6[067]|4[08])|3(?:55|60|3[0-2568]|7[013]|2[0346]|8[048]|4[0278])|0(?:06|60|77)))',
+    '107' => '(?:8(?:5(?:8[13589]|2[0-2578]|5[0-26-8]|4[356]|3[02]|0[258]|7[0579]|6[0357]|1[15])|6(?:42|8[06]|2[023578]|6[6-8]|1[15-79]|0[14]|7[46]|3[0-3689]|5[05])|4(?:34|56|77|2[03]|0[134]|1[0-24679]|8[24]|6[067]|4[08])|3(?:55|3[0-2568]|7[013]|2[0346]|6[09]|8[048]|4[0278])|0(?:06|60|77)))',
     '108' => '(?:(?:8(?:5(?:7[01358]|3[02369]|0[1-35-79]|6[124-8]|4[03-578]|5[0-35-9]|2[035]|1[0258]|8[0-3568])|3(?:1[1357]|3[13489]|6[0168]|0[357]|8[0134689]|7[0-37-9]|5[0158]|4[15]|2[0-35689])|4(?:85|0[347]|6[67]|5[16]|2[013-5]|3[029]|1[0-24-7]|7[0478]|4[48])|2(?:7[05-8]|4[128]|8[02]|0[1-38]|3[0-4]|5[05]|1[01]|2[0-28])|6(?:50|1[0-2568]|4[0-2468]|0[126-8]|3[235-8]|2[0-28])|0(?:[25]0|11|8[08]|7[01]|0[15])|7(?:23|1[03]|0[1-37])|117)|63(?:50|63)))',
     '109' => '(?:8792)',
-    '110' => '(?:8(?:5(?:6[0-25-7]|5[03589]|4[0134689]|0[1-357-9]|7[35-9]|3[0-79]|1[0-3578]|2[0-478]|8[02-468])|6(?:97|0[2359]|2[0-24-68]|6[0-259]|5[34]|4[245]|1[03-57-9]|3[058]|7[135-8]|8[015-8])|7(?:45|8[027]|5[057]|1[2-6]|0[168]|3[36]|2[1-35])|80[78]|408))',
+    '110' => '(?:8(?:5(?:6[0-25-7]|5[03589]|4[0134689]|0[1-357-9]|7[35-9]|3[0-79]|1[0-3578]|2[0-478]|8[02-468])|6(?:97|0[2359]|2[0-24-68]|6[0-259]|5[34]|4[245]|1[03-57-9]|3[0158]|7[135-8]|8[015-8])|7(?:45|8[027]|5[057]|1[2-6]|0[168]|3[36]|2[1-35])|80[78]|408))',
     '111' => '(?:8(?:6(?:3[01379]|5[056]|[12][0-258]|7[6-8]|8[1368]|4[02]|0[2568]|6[16])|5(?:43|1[0-258]|8[058]|5[568]|3[0-49]|7[57]|6[0167]|2[125]|0[125-8])|7(?:[56]5|[89]8|21|0[178]|1[01])|081))',
-    '112' => '(?:8(?:6(?:90|0[167]|2[02579]|4[24]|7[0178]|8[0-578]|3[02-5]|1[0-28]|6[02-478]|5[0-2457])|5(?:8[025]|4[018]|6[02369]|3[138]|2[248]|0[1-35689]|5[015-8]|1[0-24-6]|7[02-6])|7(?:10|33|0[12])|0(?:[01]1|88)))',
-    '113' => '(?:8(?:4(?:8[348]|4[148]|7[1479]|2[0-3]|1[0-358]|6[2-6]|3[13-5]|5[0169]|0[1248])|5(?:70|86|0[13-579]|6[0-46]|4[1369]|1[0379]|2[014-6]|3[04-6]|5[1356])|6(?:6[0-3]|3[38]|5[04-8]|8[167]|1[0-2]|0[1-48])|7(?:01|1[129])|311))',
+    '112' => '(?:8(?:6(?:90|0[167]|2[02579]|4[24]|7[0178]|8[0-578]|3[02-5]|1[0-28]|6[02-478]|5[0-2457])|5(?:4[018]|6[02369]|3[138]|8[0235]|2[248]|0[1-35689]|5[015-8]|1[0-24-6]|7[02-6])|7(?:10|33|0[12])|0(?:[01]1|88)))',
+    '113' => '(?:8(?:4(?:8[348]|4[148]|7[1479]|2[0-3]|1[0-358]|6[2-6]|3[13-5]|5[0169]|0[1248])|5(?:0[13-579]|6[0-46]|4[1369]|1[0379]|2[014-6]|3[04-6]|5[1356])|6(?:6[0-3]|3[38]|5[04-8]|8[167]|1[0-2]|0[1-48])|7(?:01|1[129])|311))',
     '114' => '(?:8(?:5(?:95|0[1-35-8]|8[013-58]|6[0-25]|4[013-5]|1[02-57-9]|7[147]|2[0-2468]|5[02-57]|3[0-24589])|6(?:11|86|0[2-6])))',
     '115' => '(?:8(?:5(?:55|67|8[568]|1[01]|2[49])|(?:60|71)1))',
     '116' => '(?:8(?:5(?:71|6[127]|2[1-4]|5[0-26]|8[014-8]|4[013689]|0[1-3578]|3[237])|611))',
@@ -134,7 +134,7 @@ our %ZIP_TABLE = (
     '136' => '(?:8(?:5(?:4[03]|1[2357]|3[13]|7[057]|6[07]|5[05]|8[0189]|0[1257]|2[1-35])|6(?:[68]6|3[057]|0[357]|7[0157]|2[0267]|4[08]|1[125])|7(?:[23]3|11)|405|880|908))',
     '137' => '(?:8(?:6(?:23|50|86)|08[18]|581))',
     '140' => '(?:8(?:5(?:90|8[03]|7[1-36]|4[0-37-9]|3[013689]|6[0367]|2[013569]|0[125-8]|5[0-28]|1[1256])|6(?:7[02578]|4[04]|0[17]|6[0168]|1[13-79]|2[13568]|8[078]|3[01479]|5[03568])|7(?:88|1[015-7]|2[12]|0[279])))',
-    '141' => '(?:8(?:6(?:3[0137-9]|2[01389]|4[0-36-8]|0[2-6]|7[0-36]|1[01568]|8[0136-8]|5[035-8]|6[024-68])|5(?:2[0-2569]|4[04]|0[13-578]|8[02-58]|1[024579]|3[03-5]|5[05-79]|6[015-8]|7[1256])|4(?:2[0-3]|1[1-9])|7(?:0[127]|1[05])|001))',
+    '141' => '(?:8(?:6(?:3[0137-9]|2[01389]|0[2-6]|7[0-36]|1[01568]|8[0136-8]|4[0-46-8]|5[035-8]|6[024-68])|5(?:2[0-2569]|4[04]|0[13-578]|8[02-58]|1[024579]|3[03-5]|5[05-79]|6[015-8]|7[1256])|4(?:2[0-3]|1[1-9])|7(?:0[127]|1[05])|001))',
     '142' => '(?:8(?:5(?:[01]1|22|33|40|67|5[058]|8[58])|6(?:11|39|66)))',
     '143' => '(?:(?:85(?:28|70|5[02578]|3[13589]|0[24-8]|8[05]|6[04578]|4[014]|1[145])|6501))',
     '144' => '(?:8(?:5(?:25|44|5[015]|3[0-356]|7[057]|1[01356]|8[08]|0[56])|6(?:02|35|2[1-3]|5[056]|7[78]|1[014]|6[01])))',
@@ -149,11 +149,11 @@ our %ZIP_TABLE = (
     '156' => '(?:8(?:5(?:22|33|55|8[58]|0[126]|1[01])|666))',
     '157' => '(?:85(?:01|43|50|6[1-35-7]|3[05]|2[0-2]|1[01]|7[035]))',
     '158' => '(?:8(?:5(?:0[12589]|5[0-2578]|3[013]|1[0-48]|6[67]|4[349]|2[0235]|7[578]|8[03568])|6(?:28|40|66|1[015]|3[0-3]|0[12])|7[07]1))',
-    '160' => '(?:8(?:3(?:8[39]|4[13]|0[14689]|1[169]|6[1689]|5[1578]|2[1457]|3[013-68]|7[457])|5(?:30|1[0-259]|4[379]|8[0-35-9]|2[0-249]|6[05]|5[57]|7[157]|0[15])|4(?:44|1[015]|3[13]|7[27]|2[0-39]|5[01]|0[1-378]|8[457-9])|(?:68|91)0|0(?:01|70)))',
+    '160' => '(?:8(?:3(?:8[39]|4[13]|0[14689]|1[169]|6[1689]|5[1578]|2[1457]|3[013-68]|7[457])|5(?:30|1[0-259]|4[379]|8[0-35-9]|2[0-249]|6[05]|5[57]|7[157]|0[15])|4(?:1[015]|3[13]|4[47]|7[27]|2[0-39]|5[01]|0[1-378]|8[457-9])|(?:68|91)0|0(?:01|70)))',
     '161' => '(?:8(?:5(?:08|3[19]|6[057]|5[1-46-8]|2[0158]|7[05]|4[015-7]|1[01])|710))',
-    '162' => '(?:8(?:6(?:80|3[0368]|5[045]|1[124-6]|6[689]|7[026]|4[046]|0[1248]|2[0246-9])|5(?:8[057]|1[25]|4[013]|7[57]|2[279]|5[16-8]|3[035]|6[0258]|0[1-35])|4(?:33|64|5[015]|0[1257-9]|7[1368]|8[048]|2[12]|4[05689]|1[125])|8(?:30|53|0[1-7]|6[01])|7(?:1[016-8]|0[1578])|0(?:01|22|55)|953))',
+    '162' => '(?:8(?:6(?:80|3[0368]|5[045]|1[124-6]|6[689]|7[026]|4[046]|0[1248]|2[0246-9])|5(?:1[25]|4[013]|7[57]|2[279]|5[16-8]|8[0357]|3[035]|6[0258]|0[1-35])|4(?:33|64|5[015]|0[1257-9]|7[1368]|8[048]|2[12]|4[05689]|1[125])|8(?:30|53|0[1-7]|6[01])|7(?:1[016-8]|0[1578])|0(?:01|22|55)|953))',
     '163' => '(?:(?:0(?:6(?:88|7[5-7]|5[59]|6[3579])|5(?:7[056]|5[37-9]|6[069])|4(?:56|6[067]|7[08])|7(?:77|2[79]|3[013])|8(?:50|67|3[136])|9(?:43|3[589])|2(?:78|6[89]))|1(?:3(?:50|6[38]|8[28]|7[18]|4[589])|4(?:55|70|6[29]|8[08])|0(?:71|5[35]|6[56])|5(?:55|88|3[37]))|8(?:6(?:[18]0|02|26|7[127]|3[89]|6[016])|0(?:0[13]|8[0-2]|1[29])|5(?:35|48)|339)))',
-    '164' => '(?:8(?:5(?:[12]2|[67]7|30|41|8[58]|5[05]|0[13-5])|6(?:[25]0|[37]8|66|8[26]|1[17]|4[24])|7(?:01|25)))',
+    '164' => '(?:8(?:5(?:[12]2|[67]7|30|8[58]|5[05]|0[13-5]|4[01])|6(?:[25]0|[37]8|66|8[26]|1[17]|4[248])|7(?:01|25)))',
     '165' => '(?:8(?:555|780))',
     '166' => '(?:8(?:5(?:20|55|3[13589]|6[5-7]|4[025]|0[1-36]|8[58]|7[078])|6(?:01|10)))',
     '167' => '(?:8(?:5(?:[24]0|85|7[78]|3[34]|6[07]|0[167]|1[05]|5[15])|6(?:10|28|0[12])|0(?:01|70)))',
@@ -180,7 +180,7 @@ our %ZIP_TABLE = (
     '189' => '(?:85(?:[01]1|85|5[05]|2[01]))',
     '190' => '(?:(?:8(?:5(?:3[015-79]|6[0-25-7]|5[013-578]|8[1-3689]|0[135-9]|7[1-358]|1[013-9]|4[034]|2[0-28])|6(?:66|8[0168]))|129[2357]|0192))',
     '191' => '(?:8(?:5(?:20|55|0[1-35-79]|1[0-2])|6(?:60|86)))',
-    '192' => '(?:(?:8(?:5(?:77|85|1[0-2568]|2[025]|6[28]|5[1368]|3[235-8]|0[125-8])|6(?:11|22|33|5[015]|4[48])|702)|0(?:9(?:9[2-4]|8[1-3689])|39[2-8])))',
+    '192' => '(?:(?:8(?:5(?:77|85|1[0-2568]|2[025]|6[28]|5[1368]|3[235-8]|0[125-8])|6(?:11|22|33|5[015]|4[48])|702)|0(?:9(?:9[1-4]|8[1-3689])|39[2-8])))',
     '193' => '(?:(?:8(?:5(?:[57]0|33|2[05]|1[01]|0[15])|6[68]6)|09(?:85|9[178])))',
     '194' => '(?:(?:8(?:5(?:77|1[015]|4[03]|0[23578]|8[0568]|5[0158]|2[07]|6[067]|3[038])|6(?:66|1[0-2]))|029[2-8]))',
     '195' => '(?:85(?:85|5[05]))',
@@ -196,13 +196,13 @@ our %ZIP_TABLE = (
     '207' => '(?:85(?:[18]5|01))',
     '208' => '(?:85(?:85|0[1-3]|5[05]))',
     '210' => '(?:(?:8(?:5(?:2[1-3]|5[027-9]|6[0259]|3[1278]|0[1246]|7[0167]|8[36]|1[125]|4[014578])|6(?:66|0[14]|8[016]))|9(?:5(?:[06]7|11|26|55|3[03]|8[28])|650)))',
-    '211' => '(?:8(?:5(?:[2-4]0|66|5[058]|7[07]|8[58]|1[01]|0[125])|6(?:11|6[68])))',
+    '211' => '(?:8(?:5(?:[2-4]0|66|5[058]|7[07]|8[58]|1[01]|0[125])|6(?:[01]1|6[68])))',
     '212' => '(?:8(?:5(?:44|90|1[13]|0[1-389]|6[03467]|8[1-489]|2[05]|7[0267]|5[1457]|3[01])|602))',
     '213' => '(?:85(?:66|2[0-35]|0[2357]|5[01389]|3[35]|7[0367]|8[015-9]|1[125]|4[56]))',
     '214' => '(?:85(?:[26]5|33|8[058]|7[01]))',
     '215' => '(?:85(?:[36]0|09|42|7[06]|1[015]|8[58]|5[08]|2[017]))',
     '216' => '(?:85(?:[56]6|22|70|1[0-249]|0[125]))',
-    '220' => '(?:8(?:5(?:58|77|1[015]|3[69]|2[0-3]|8[058]|0[12]|4[0-2]|6[56])|6(?:53|8[06]|0[149]|1[1-6]|2[02]|7[48]|6[08])|080|711))',
+    '220' => '(?:8(?:5(?:58|77|1[015]|3[69]|2[0-3]|8[058]|0[12]|4[0-2]|6[56])|6(?:53|8[06]|0[149]|1[1-6]|2[02]|7[48]|6[08])|7(?:11|22)|080))',
     '221' => '(?:8(?:5(?:[46]0|37|88|1[17]|5[058]|2[023])|7(?:12|41|65|0[1-35])|6(?:11|23|66|8[68])))',
     '222' => '(?:8(?:5(?:77|3[03]|8[056]|6[1-6]|0[157-9]|1[15]|5[0268]|2[035])|6[25]2))',
     '223' => '(?:8(?:5(?:1[025]|2[0-356]|[58][058]|7[27]|6[067]|4[0-2]|0[125-8]|3[039])|68[67]))',
@@ -232,7 +232,7 @@ our %ZIP_TABLE = (
     '250' => '(?:(?:0(?:2(?:80|9[2-68])|39[28]|[15]92)|85(?:11|55|88)))',
     '251' => '(?:8(?:5(?:40|2[02]|5[0158]|1[0135]|6[067]|8[18]|3[014]|0[125])|601))',
     '252' => '(?:(?:5(?:2(?:01|33|77|8[0568]|5[258]|1[01]|2[125]|9[2-578])|1(?:[56]2|8[128]|7[27]|9[126]))|0(?:3(?:7[03-57]|9[258]|8[013568])|88[0-3568])|85(?:[02]2|[47]0|11|85|3[89]|6[67]|5[08])|119[235]))',
-    '253' => '(?:(?:8(?:5(?:[03]1|10|22|43|67|7[17]|5[058]|8[58])|686)|019[235-8]))',
+    '253' => '(?:(?:8(?:5(?:[03]1|10|22|43|67|7[17]|5[058]|8[58])|686)|019[25-8]))',
     '254' => '(?:8(?:5(?:43|55|8[58]|0[12]|3[023])|6(?:01|86|1[024])))',
     '255' => '(?:8555)',
     '256' => '(?:8510)',
@@ -453,7 +453,7 @@ our %ZIP_TABLE = (
     '479' => '(?:8(?:5(?:01|55|77|1[018]|8[5689])|7(?:87|0[1-8]|1[12])|6(?:01|10|23|68)))',
     '480' => '(?:(?:0(?:2(?:8[128]|9[1246])|19[23578]|39[235])|1(?:1(?:8[89]|9[2-9])|298)))',
     '481' => '(?:8(?:5(?:26|88|4[03]|5[058]|1[0135]|0[1-58]|3[1359])|6(?:[08]1|15|78)))',
-    '482' => '(?:8(?:5(?:01|30|55|1[01])|6(?:86|5[12])))',
+    '482' => '(?:8(?:5(?:01|55|1[01])|6(?:86|5[12])))',
     '483' => '(?:8(?:5(?:55|0[2357])|70[14]))',
     '484' => '(?:8(?:5(?:0[1-8]|1[01])|609))',
     '485' => '(?:8(?:5(?:05|40|1[0-26]|2[0-3]|3[013]|5[0-25]|6[1-35])|65[0-5]|750))',
@@ -499,7 +499,7 @@ our %ZIP_TABLE = (
     '527' => '(?:(?:8(?:5(?:[27]7|42|8[058]|6[67]|1[12]|5[0458]|0[589])|687)|0195))',
     '528' => '(?:8(?:5(?:[58]5|0[12]|1[01])|666))',
     '529' => '(?:(?:1(?:3(?:93|8[0-368])|59[2578]|49[235]|69[28]|195|892)|0(?:49[238]|[27]92)))',
-    '530' => '(?:8(?:2(?:6[26]|1[0-25-7]|8[128]|5[12]|4[157]|7[08]|2[267]|0[13-6]|3[049])|5(?:01|44|2[1-3]|6[05-7]|5[1568]|7[45]|8[02368]|3[15]|1[1-37])|3(?:18|2[34]|8[389]|4[16]|5[05]|[03][48])|6(?:1[018]|0[12]|8[08])|4(?:75|1[015]|4[18])|79[136-8]))',
+    '530' => '(?:8(?:2(?:6[26]|8[128]|1[0-35-7]|5[12]|4[157]|7[08]|2[267]|0[1-69]|3[049])|5(?:01|44|2[1-3]|6[05-7]|5[1568]|7[45]|8[02368]|3[15]|1[1-37])|3(?:18|2[34]|8[389]|4[16]|5[05]|[03][48])|6(?:1[018]|0[12]|8[08])|4(?:75|1[015]|4[18])|79[136-8]))',
     '531' => '(?:8(?:5(?:67|0[1-3]|5[58]|1[01])|787))',
     '532' => '(?:8(?:5(?:35|60|77|2[045]|8[58]|0[1578]|5[0258]|1[145])|680))',
     '533' => '(?:8(?:5(?:33|85|5[58]|0[12])|651))',
@@ -510,7 +510,7 @@ our %ZIP_TABLE = (
     '538' => '(?:8(?:5(?:[58]5|01|10)|6(?:[68]6|55)))',
     '539' => '(?:8794)',
     '540' => '(?:(?:8(?:5(?:66|4[0147]|2[1267]|5[01589]|0[158]|3[03-5]|7[01578]|1[0-2579]|8[14-8])|6(?:20|8[69]|4[25]|3[09]|0[2-8]|7[078]|6[08]|1[01])|795)|6255))',
-    '541' => '(?:(?:85(?:5[0136-9]|2[013-689]|8[15-79]|7[1568]|4[0-35-9]|1[126-8]|6[368]|0[1-689]|3[014578])|6666))',
+    '541' => '(?:(?:85(?:5[0136-9]|2[013-689]|8[15-79]|7[1568]|4[0-35-8]|0[1-35689]|1[126-8]|6[368]|3[014578])|6666))',
     '542' => '(?:8(?:5(?:33|42|77|0[1-4]|8[0568]|6[67]|2[235]|5[0458]|1[01])|6(?:54|60|8[68])|745))',
     '543' => '(?:8(?:5(?:[34]3|11|[58][58]|0[12])|6(?:01|66|8[68])))',
     '544' => '(?:8(?:5(?:01|55)|666))',
@@ -528,7 +528,7 @@ our %ZIP_TABLE = (
     '557' => '(?:8501)',
     '558' => '(?:85(?:01|85|5[58]))',
     '559' => '(?:8(?:5(?:01|1[019]|5[03589]|8[58]|6[01])|6(?:[01]1|5[18])|729))',
-    '560' => '(?:85(?:05|79|80|4[38]|5[25]|6[0157]|3[12]))',
+    '560' => '(?:85(?:79|80|4[38]|5[25]|6[0157]|3[12]|0[56]))',
     '561' => '(?:85(?:[06]1|20|77|5[058]|1[01]))',
     '562' => '(?:8(?:5(?:11|22|43|8[0568]|[05][58]|6[0278])|686))',
     '563' => '(?:(?:85(?:[67]7|10|88)|0[23]92))',
@@ -559,11 +559,11 @@ our %ZIP_TABLE = (
     '590' => '(?:(?:8(?:5(?:[34]0|03|77|2[27-9]|1[17]|6[07]|8[58]|5[01])|686)|0(?:4(?:9[3-6]|8[12])|592)))',
     '591' => '(?:85(?:11|55|0[125]))',
     '592' => '(?:8585)',
-    '594' => '(?:(?:850[12]|1198))',
+    '594' => '(?:(?:8(?:50[12]|686)|1198))',
     '595' => '(?:8(?:5(?:85|5[58])|6(?:50|86)))',
     '596' => '(?:8(?:6(?:[25]4|86)|510))',
     '597' => '(?:8(?:5(?:22|43|55|8[58]|0[12]|1[15])|686))',
-    '598' => '(?:85(?:[13]1|22|6[06]|0[38]|5[05]))',
+    '598' => '(?:85(?:[13]1|22|6[06]|0[389]|5[05]))',
     '599' => '(?:(?:0[23]92|8531))',
     '600' => '(?:8(?:5(?:40|3[03]|1[019]|5[058]|8[1568]|7[07]|6[67]|0[1-35])|6(?:52|77|86|6[56])|7(?:11|87)))',
     '601' => '(?:(?:85(?:01|42|50|3[03]|8[58]|1[01])|0(?:292|797)|1(?:192|495)))',
@@ -941,7 +941,7 @@ our %ZIP_TABLE = (
     '986' => '(?:(?:85(?:40|55|0[17]|2[25]|8[05])|0(?:195|792)|229[23]))',
     '987' => '(?:(?:2(?:29[23]|59[23]|195|392)|0(?:19[25]|79[23]|595)|860[23578]|139[35]))',
     '988' => '(?:(?:039[23]|850[12]))',
-    '989' => '(?:(?:1(?:69[2-5]|29[235]|39[2-4]|592|795)|6(?:1(?:9[23]|8[1358])|49[23]|[38]92)|2(?:4(?:8[0134]|9[236])|292|393)|0(?:29[2-6]|[58]92|998)|5(?:[3-5]92|69[23])|(?:32|4[15-7])92))',
+    '989' => '(?:(?:6(?:1(?:8[1358]|9[235])|49[23]|[38]92)|1(?:69[2-5]|29[235]|39[2-4]|592|795)|2(?:4(?:8[0134]|9[236])|292|393)|0(?:29[2-6]|[58]92|998)|5(?:[3-5]92|69[23])|(?:32|4[15-7])92))',
     '990' => '(?:(?:8(?:5(?:8[057]|5[0158]|1[0-29]|6[067]|4[05]|7[01578]|0[126]|2[125]|3[1359])|6(?:[24]2|06|11|68|7[078])|794)|95(?:06|59|67|78|3[06]|8[0-258])|0(?:49[23]|[37]92)|2(?:196|292)))',
     '991' => '(?:8(?:5(?:[58]5|21|1[1-3]|0[158])|6(?:01|1[03])))',
     '992' => '(?:(?:8(?:5(?:[246]0|85|5[058]|0[12]|1[01])|6(?:01|10))|0(?:39[23]|[48]92)))',
